.. _faq:

FAQ
===

Which Python versions are supported?
------------------------------------

It supports Python 3.4, 3.5, 3.6, 3.7 and 3.8.

The last version to support Python 2.7 is ``django-composite-field ==0.9.1``.

Which Django versions are supported?
------------------------------------

It supports Django 1.8, 1.9, 1.10, 1.11, 2.0, 2.1, 2.2 and 3.0.

Can I get commercial support?
-----------------------------

You can also get commercial support from the maintainer `Michael P. Jung`_
and his company `Terreon GmbH`_.

.. _Michael P. Jung: https://bikeshedder.com/
.. _Terreon GmbH: https://terreon.de/
